@@ -1,10 +1,11 @@
-__version__ = "0.8.0"
+__version__ = "0.10.0"
 
 from .collection import Collection
 from .container import Container
 from .hashable import Hashable
 from .iterable import Iterable, Iterator, Reversible
-from .sequence import Sequence
+from .mapping import Mapping
+from .sequence import MutableSequence, Sequence
 from .sized import Sized
 
 __all__ = [
@@ -13,6 +14,8 @@ __all__ = [
     "Hashable",
     "Iterable",
     "Iterator",
+    "Mapping",
+    "MutableSequence",
     "Reversible",
     "Sequence",
     "Sized",
