@@ -5,6 +5,7 @@ from typing_extensions import Protocol, runtime_checkable
 __all__ = [
     "Iterable",
     "Iterator",
+    "Reversible",
 ]
 
 
@@ -24,3 +25,12 @@ class Iterator(Protocol[T]):
 
     def __next__(self) -> T:
         ...
+
+
+@runtime_checkable
+class Reversible(Protocol[T]):
+    def __iter__(self) -> "Iterator[T]":
+        ...
+
+    def __reversed__(self) -> "Iterator[T]":
+        ...
